# tengi - Telegram bot ENGIne

Key features:
- Button clicks with no domain name needed (polling)
- Bot commands in bash-like style
- Ability to send periodic updates to other components (not only to Telegram callbacks) 
- Ability to access Telegram both as a bot and as a user
- Many useful chatbot components
